@@ -47,7 +47,6 @@ public:
   Gnote();
   ~Gnote();
   int main(int argc, char **argv);
-  std::string get_note_path(const std::string & override_path);
   NoteManager & default_note_manager()
     {
       return *m_manager;
@@ -70,7 +69,6 @@ public:
   void open_search_all();
   void open_note_sync_window();
 
-  static std::string conf_dir();
   static bool tray_icon_showing()
     {
       return s_tray_icon_showing;
@@ -84,6 +82,10 @@ public:
       m_tray = tray;
     }
 private:
+  void start_note_created(const Note::Ptr & start_note);
+  static std::string conf_dir();
+  std::string get_note_path(const std::string & override_path);
+
   NoteManager *m_manager;
   IKeybinder  *m_keybinder;
   Glib::RefPtr<Gtk::IconTheme> m_icon_theme;
@@ -113,14 +115,16 @@ public:
     }
 
 private:
+  void        print_version();
 
   bool        m_new_note;
-  bool        m_open_search;
   bool        m_open_start_here;
   bool        m_use_panel;
+  bool        m_show_version;
   std::string m_open_note_name;
   std::string m_open_note_uri;
   std::string m_open_external_note_path;
+  Glib::ustring m_search;
   Glib::ustring m_note_path;
 };
 
